Module integer

Module integer 

Enums

IntegerSign
Sign classification for a signed integer value.

Functions

are_coprime
Returns whether two integers share no positive common divisor other than one.
classify_sign
Classifies a signed integer as negative, zero, or positive.
gcd
Computes the non-negative greatest common divisor of two signed integers.
is_divisible_by
Returns whether value is evenly divisible by divisor.
is_even
Returns whether an integer is evenly divisible by two.
is_odd
Returns whether an integer leaves a remainder of one when divided by two.
lcm
Computes the non-negative least common multiple of two signed integers.